@@ -1,13 +1,13 @@
 package File::Rename;
 
 use strict;
-BEGIN { eval { require warnings; warnings->import } }
+use warnings;
 
 require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw( rename );
 
-our $VERSION = '2.00';
+our $VERSION = '2.00_1';
 
 sub import {
     my $pack = shift;
