@@ -1,4 +1,5 @@
 use strict;
+use warnings;
 
 require File::Spec;
 require File::Path;
@@ -31,19 +32,18 @@ sub create {
 
 sub listdir {
     my $d = shift;
-    local *DIR;
-    unless (opendir DIR, $d) { diag "Can't opendir $d: $!"; return }
-    my @read = readdir DIR;
-    closedir DIR or die $!;
+    my $DIR;
+    unless (opendir $DIR, $d) { diag "Can't opendir $d: $!"; return }
+    my @read = readdir $DIR;
+    closedir $DIR or die $!;
     return (grep {!/^\./} @read);
 }
 
 sub create_file {
     my $file = shift;
-    local *FILE; 
-    if (open  FILE, '>', $file) {
-    	print FILE @_;
-        return 1 if close FILE;
+    if (open  my $fh, '>', $file) {
+    	$fh->print(@_);
+        return 1 if close $fh;
     }
     $file =~ s/\n/\\n/g;
     $file =~ s/\s/\\ /g;
@@ -72,10 +72,11 @@ sub test_rename_function {
   my ($function, $warning, $printed) = @_;
   our($found, $print, $warn) = ();
 
-  { local *STDOUT;
-    open STDOUT, '>', \$print or die;
+  { 
+    open my $stdout, '>', \$print or die;
+    select $stdout;
     $function -> ();
-    close STDOUT or die;
+    close $stdout or die;
   }
 
     if( $warning ) {
@@ -122,12 +123,12 @@ sub options {
     
 sub is_windows {
     unless ( $] < 5.014 ) {
-	if ( eval { require Perl::OSType; } ) { 
+	    if ( eval { require Perl::OSType; } ) { 
             return Perl::OSType::is_os_type('Windows'); 
         }
         diag $@;
     }
-    return ($^O eq q{MSWin32} or $^O eq q{cygwin}) 
+    return ($^O eq q{MSWin32}) 
 } 
 
 sub script_name {
